.. role:: hidden
    :class: hidden-section
.. currentmodule:: {{ module }}

{{ name | underline}}

.. autoexception:: {{ objname }}
.. autoexception:: InvalidExampleError

.. raw:: html

     <div style='clear:both'></div>

